<?php
/**
 *
 * Habilita un conjunto de funciones para hacer más manejable el acceso a una base de datos MySQL.
 * Requiere y utiliza el componente ezSQL_mysqli de Justin Vincent (http://php.justinvincent.com)
 *
 * Basado en la clase jtMySQL de Javier Tapia
 *
 * Modificado por Patricio Bastidas
 *
 * Versión para PHP 5.5 y MySQL 4.1 **************************************************************
 */
 
class MySQL extends ezSQL_mysqli{
    
    var $log = NULL;

    /**
     * Inserta un registro indicando tabla y array de datos
     * @param string $table Nombre de la tabla
     * @param array $datos Array de datos tipo 'campo'=>valor. Valor debe estar preformateado
     * @return NULL
     */
    function insert($table,$datos){
        if($table && is_array($datos)){
            $fields = array();
            $values = array();
            foreach($datos as $k=>$v){
                $fields[] = $k;
                $values[] = $v;
            }
            $fields = implode(', ',$fields) ;
            $values = implode(', ',$values) ;
            $q = "INSERT INTO $table ($fields) VALUES ($values)";
            $this->query($q);
            $this->log.= 'Insert : '.$q."\r\n";
            return $this->insert_id;
        }
    }
    /**
     * Actualiza uno o más registros indicando tabla, arry de datos y condicional
     * @param string $table Nombre de la tabla a actualizar
     * @param array $datos Matriz de tipo nombre_del_campo=>valor
     * @param string $where Condicional SQL:WHERE
     * @return int Número de filas afectadas por el Update
     */
    function update($table,$datos,$where){
        if($table && is_array($datos) && $where){
            $values = array();
            foreach($datos as $k=>$v){
                $values[] = "$k=$v";
            }
            $values = implode(', ',$values); //trim(trim($values),',');
            $q = "UPDATE $table SET $values" . $this->where($where);
            $this->query($q);
            $this->log.= 'Update : ' . $q . ' : ' . affected_rows . "\r\n";
			$this->rows_affected = @$this->dbh->affected_rows;
			$return_val = $this->rows_affected;
            return $return_val;
        }
    }
    /**
     * Muestra un conjunto de arrays  resultado de una consulta a la base de datos
     * @param string $table Nombre de la tabla
     * @param string $fields Campo(s) incluidos en la consulta
     * @param string $where Condicional WHERE de SQL
     * @param string $order Opción ORDER BY de SQL
     * @param string $limit Opción LIMIT de SQL
     * @return array Juego de resultados ordenados como array, donde cada elemento (fila) es un array (campos)
     */
    function results($table, $fields='*', $where=null, $order=null, $limit=null){
        $q = "SELECT $fields FROM $table" . $this->where($where) . $this->order($order) . $this->limit($limit);
        $this->log.= $q."\r\n";
        return $this->get_results($q);
    }
    /**
     * Muestra un array resultado de una consulta a la base de datos
     * @param string $table Nombre de la tabla
     * @param string $fields Campo(s) incluidos en la consulta
     * @param string $where Condicional WHERE de SQL
     * @return array Array de datos name_of_field=>field_data
     */
    function row($table, $fields='*', $where=null, $order=null, $limit=null){
        $q = "SELECT $fields FROM $table" . $this->where($where) . $this->order($order) . $this->limit($limit);
        $this->log.= $q."\r\n";
        return $this->get_row($q);
    }
    /**
     * Elimina los registros coincidentes
     * @param string $table Nombre de la tabla
     * @param string $where Condicional WHERE de SQL
     * @return bool True si la tabla existe o tiene datos que cumplan la condición
     */
    function delete($table,$where=NULL){
        if($table && $where){
            $q = "DELETE FROM $table" . $this->where($where);
            $this->log.= $q."\r\n";
            return $this->query($q);
        }
    }
    /**
     * Verifica si existe una tabla, o si tiene datos que cumplan la condición
     * @param string $table Nombre de la tabla
     * @param string $where Condicional WHERE de SQL
     * @return bool True si la tabla existe o tiene datos que cumplan la condición
     */
    function siHay($table,$where=null){
        if(@$table) {
            $this->log.= 'SiHay : ';
            if ($this->count($table,$where)==0) return false;
            return true;
        }
    }
    /**
     * Devuelve el valor de una variable
     * @param string $table Nombre de la tabla
     * @param string $field Nombre del campo que se consultará
     * @param string $where Condicional WHERE de SQL
     * @return string Valor devuelto por la consulta SQL
     */
    function getVar($table,$field,$where=null){
        $q = "SELECT $field FROM $table" . $this->where($where);
        if($table && $field) { $r = $this->get_var( $q ); }
        $this->log.= 'getVar  '.$q." : ".$r."\r\n";
        return $r;
    }
	/**
     * Devuelve el valor de una variable para el ordenamiento
     * @param string $table Nombre de la tabla
     * @param string $field Nombre del campo que se consultará
     * @param string $where Condicional WHERE de SQL
     * @return string Valor devuelto por la consulta SQL
     */
    function getVarOrden($table,$field,$where=null, $order=null, $limit=null){
        $q = "SELECT $field FROM $table" . $this->where($where) . $this->order($order) . $this->limit($limit);
        if($table && $field) { $r = $this->get_var( $q ); }
        $this->log.= 'getVar  '.$q." : ".$r."\r\n";
        return $r;
    }
	/**
     * Devuelve la cadena correspondiente al idioma
	 * Si no encuentra resultados devuelve la frase recibida
     * @param string $frase Cadena para traducir
     * @param string $idioma Idioma
     */
    function translate($frase_traducir=NULL,$idioma_traducir){
		$where = "es='{$frase_traducir}'";
        $q = "SELECT $idioma_traducir FROM idiomas" . $this->where($where);
        if($frase_traducir && $idioma_traducir) { $r = $this->get_var( $q ); }
        $this->log.= 'translate '.$q." : ".$r."\r\n";
		if(empty($r)) { $r=$frase_traducir; }
        return $r;
    }
    /**
     * Establece el registro de errores
     * @param bool $status Establece si se registrará o no los errores
     */
    public function verLog($data=null){
        ob_start();
        echo mysql_error();
        if($data){
            if(is_array($data)) { print_r($data); }
                else            { echo $data; }
        }
        $this->log = '<pre>'.$this->log."\r\n".ob_get_contents().'</pre>';
		ob_end_clean();
        return $this->log;
    }
    /**
     * Elimina el registro de errores
     */
    public function clearLog(){
        $this->log = NULL;
    }

    /**
     * Devuelve la cantidad de filas que contiene una determinada tabla
     * @param string $table Nombre de la tabla
     * @param string $where Condicional WHERE de SQL
     * @return string Número : cantidad de filas afectadas
     */
    function count($table,$where=null){
        return $this->getVar($table,'COUNT(*)',$where);
     }
    /**
     * Formatea la sección WHERE de la consulta
     * @param string $where Condicional WHERE de SQL
     * @return string WHERE formateado
     */
    function where($where=null){
        if (!empty($where)) return " WHERE $where ";
    }
    /**
     * Formatea la sección ORDER de la consulta
     * @param string $order Parámetro ORDER de SQL
     * @return string ORDER formateado
     */
    function order($order=null){
        if(!empty($order)) return " ORDER BY $order ";
    }
    /**
     * Formatea la sección LIMIT de la consulta
     * @param string $limit Parámetro LIMIT de SQL
     * @return string LIMIT formateado
     */
    function limit($limit=null){
        if(!empty($limit)) return " LIMIT $limit "; }


    /**
     * Prepara un string para hacerlo safe-query
     * @param string $string Texto a formatear
     * @return string
     */
    function string($string,$html=null){
        $string = trim($string);
        if(!isset($html)) $string = strip_tags($string);
        if(@get_magic_quotes_gpc()) { return "'".$string."'"; }
                               else { return "'".addslashes($string)."'"; }
    }
    /**
     * Devuelve el ID del último registro insertado
     * @return int
     */
    function UltimoId($table=NULL){
        if($table) return $this->getVar($table, 'MAX(id)');
        return $this->insert_id;
    }
    /**
     * Devuelve la suma de los campos
     * @param string $table Nombre de la tabla
     * @param string $field Nombre del campo
     * @param string $where Condicional WHERE de SQL
     * @return string Valor devuelto por la consulta SQL
     */
    function Suma($table,$field,$where=null){
        $q = "SELECT SUM($field) FROM $table" . $this->where($where);
        if($table && $field) { $r = $this->get_var( $q ); }
        return $r;
    }
    function __tostring(){
        return $this->VerLog();
    }
}
